@@ -4,12 +4,22 @@
   fi
   mv aliases-new aliases
 )
+
+( cd etc
+  if  ! grep submission services 1>/dev/null 2>/dev/null; then
+     cat >> services << EOF2
+submission      587/tcp
+submission      587/udp
+EOF2
+      killall -HUP inetd
+  fi
+)
     
 (  cd etc/postfix
   if [ ! -d backup ]; then
       mkdir backup
   fi
-  for i in LICENSE TLS_LICENSE access aliases canonical generic header_checks main.cf main.cf.default makedefs.out master.cf post-install postfix-files postfix-script relocated transport virtual  ; do
+  for i in LICENSE TLS_LICENSE access aliases canonical generic header_checks main.cf main.cf.default makedefs.out master.cf post-install postfix-files postfix-script relocated transport virtual bounce.cf.default ; do
     if [ -f $i ]; then
          mv $i backup/$i
     fi
